# -*- coding: UTF-8 -*-

'''
nvidia-smi -i 0 --format=csv --query-gpu=pstate,utilization.memory,utilization.gpu
pstate, utilization.memory [%], utilization.gpu [%]
P8, 0 %, 0 %
'''

'''
return :
-1           : cmd not found
-2           : cmd err
nonnegative  : ok 
'''

import os
import sys


CMDPATH = r'C:\Program Files\NVIDIA Corporation\NVSMI\nvidia-smi.exe'
def if_gpu():
    if os.access(CMDPATH, os.F_OK):
        return True
    else:
        return False

def gpu_info(gpuNum, item):
    if not if_gpu():
        return -1
    
    cmdline = '"' + CMDPATH + '"' + ' --format=csv --query-gpu=pstate,utilization.memory,utilization.gpu -i %d'%gpuNum
    gpuinfos=os.popen(cmdline).readlines()
    if not gpuinfos[0].startswith('pstate'):
        return -2
        
    gpuinfo = {}
    try:
        gpuinfo['Perf'] = gpuinfos[1].split(',')[0]
        gpuinfo['MemUsage'] = round(float(gpuinfos[1].split(',')[1].split()[0]), 2)
        gpuinfo['GpuUtil'] = round(float(gpuinfos[1].split(',')[2].split()[0]), 2)
    except:
        return -2

    return gpuinfo[item]



def main(gpuNum=None, item=None):
    print(gpu_info(gpuNum, item))


if __name__ == '__main__':
    opts = ['Perf', 'MemUsage', 'GpuUtil']
    if len(sys.argv) != 3 or sys.argv[2] not in opts or not sys.argv[1].isdigit():
        print("arg err!(get_gpu_info.py 0|1|2... Perf|MemUsage|GpuUtil)")
        sys.exit()
    
    main(gpuNum=int(sys.argv[1]), item=sys.argv[2])